Installing Bika LIMS
====================

Please follow these steps to install Plone:

https://docs.plone.org/4/en/manage/installing/index.html

To install Bika LIMS, you simply have to add `bika.lims` into the `eggs` section
of your `buildout.cfg`::

  eggs =
    ...
    bika.lims

Also see this section of the Plone documentation for further details:
https://docs.plone.org/4/en/manage/installing/installing_addons.html
